PROFANITY_LIST = {
    # Common swear words
    "fuck", "fucking", "fucked", "fucker", "motherfucker", "fucks", "fuk", "fck", "f u c k",
    "shit", "shitty", "shite", "bullshit", "horseshit", "sh1t", "sh1te",
    "ass", "asshole", "arse", "arsehole", "asshat", "asswipe",
    "bitch", "bitches", "b1tch", "b1tches",
    "dick", "d1ck", "dickhead", "dickweed",
    "cunt", "cunts", "c*nt", "cuntface",
    "cock", "c0ck", "cocksucker", "cockhead",
    "piss", "pissed", "pissing", "piss off",
    "bastard", "bastards",
    "wanker", "wank", "w4nk", "wanker",
    "twat", "twats",
    "prick", "pricks",

    # Slurs and hate speech (use with extreme caution and context)
    "nigger", "n1gger", "niggah", "nigga",
    "faggot", "fag", "f4g", "faggots",
    "retard", "retarded", "tard",
    "chink", "gook", "spic", "wetback", "kike", "raghead", "sandnigger",

    # Sexual/explicit terms
    "tits", "titties", "boobs", "boobies",
    "pussy", "pussies",
    "clit", "clitoris",
    "blowjob", "bj", "suck dick", "deepthroat",
    "cum", "cumming", "jizz", "spunk",
    "porn", "porno", "xxx",

    # Combinations and evasions
    "f@ck", "f**k", "fu*k", "f.u.c.k", "phuck", "fuhk",
    "sh!t", "s h i t", "sh*t",
    "b!tch", "b*tch",
    "c*nt", "cuntz",
    "a55", "a$$", "a55hole",

    # Miscellaneous offensive
    "whore", "slut", "skank", "hoe", "ho",
    "douche", "douchebag",
    "crap", "crappy",
    "damn", "goddamn", "goddammit", "god damn",
    "hell", "hel", "h3ll",
    "jesus christ", "jesus fucking christ",
}

# Case-insensitive matching
PROFANITY_SET = {word.lower() for word in PROFANITY_LIST}